Ontology Specifications
--

This folder contains the specifications of the core ontology used to build 
the Forte projects. 

 - The `base_ontology.json` file defines the core NLP types. The generated files
   can be found at `ft.onto.base_ontology.py`
 - The `race_qa_onto.json` demonstrate how to create ontology for a QA task.
   The generated files can be found at `ft.onto.race_multi_choice_qa_ontology.py`
